==> kubernetes-model-admissionregistration-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/admission/v1beta1/AdmissionReviewFluent.java <==
package io.fabric8.kubernetes.api.model.admission.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface AdmissionReviewFluent<A extends io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionRequest getRequest();
    public A withRequest(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionRequest request);
    public Boolean hasRequest();
    
/**
 * This method has been deprecated, please use method buildResponse instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionResponse getResponse();
    public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionResponse buildResponse();
    public A withResponse(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionResponse response);
    public Boolean hasResponse();
    public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent.ResponseNested<A> withNewResponse();
    public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent.ResponseNested<A> withNewResponseLike(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionResponse item);
    public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent.ResponseNested<A> editResponse();
    public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent.ResponseNested<A> editOrNewResponse();
    public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent.ResponseNested<A> editOrNewResponseLike(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionResponse item);
    public interface ResponseNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionResponseFluent<io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent.ResponseNested<N>> {

            public N and();
            public N endResponse();    }


}

==> kubernetes-model-admissionregistration-5.4.1-sources.jar: io/fabric8/kubernetes/api/model/admission/v1beta1/AdmissionReviewFluent.java <==
package io.fabric8.kubernetes.api.model.admission.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface AdmissionReviewFluent<A extends io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public java.lang.String getApiVersion();
    public A withApiVersion(java.lang.String apiVersion);
    public java.lang.Boolean hasApiVersion();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withApiVersion instead.
     */
        public A withNewApiVersion(java.lang.String arg0);
    public java.lang.String getKind();
    public A withKind(java.lang.String kind);
    public java.lang.Boolean hasKind();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withKind instead.
     */
        public A withNewKind(java.lang.String arg0);
    public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionRequest getRequest();
    public A withRequest(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionRequest request);
    public java.lang.Boolean hasRequest();
    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildResponse instead.
     * @return The buildable object.
     */
        public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionResponse getResponse();
    public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionResponse buildResponse();
    public A withResponse(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionResponse response);
    public java.lang.Boolean hasResponse();
    public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent.ResponseNested<A> withNewResponse();
    public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent.ResponseNested<A> withNewResponseLike(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionResponse item);
    public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent.ResponseNested<A> editResponse();
    public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent.ResponseNested<A> editOrNewResponse();
    public io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent.ResponseNested<A> editOrNewResponseLike(io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionResponse item);
    public interface ResponseNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionResponseFluent<io.fabric8.kubernetes.api.model.admission.v1beta1.AdmissionReviewFluent.ResponseNested<N>> {

            public N and();
            public N endResponse();    }


}
